@@ -233,38 +233,40 @@ impl POEntry {
 
     pub fn unescaped(&self) -> Result<Self, EscapingError> {
         let mut entry = self.clone();
-        entry.msgid = unescape(&self.msgid)?;
+        entry.msgid = unescape(&self.msgid)?.to_string();
 
         if let Some(msgstr) = &self.msgstr {
-            entry.msgstr = Some(unescape(msgstr)?);
+            entry.msgstr = Some(unescape(msgstr)?.to_string());
         }
 
         if let Some(msgid_plural) = &self.msgid_plural {
-            entry.msgid_plural = Some(unescape(msgid_plural)?);
+            entry.msgid_plural =
+                Some(unescape(msgid_plural)?.to_string());
         }
 
         for msgstr_plural in &mut entry.msgstr_plural {
-            *msgstr_plural = unescape(msgstr_plural)?;
+            *msgstr_plural = unescape(msgstr_plural)?.to_string();
         }
 
         if let Some(msgctxt) = &self.msgctxt {
-            entry.msgctxt = Some(unescape(msgctxt)?);
+            entry.msgctxt = Some(unescape(msgctxt)?.to_string());
         }
 
         if let Some(previous_msgid) = &self.previous_msgid {
-            entry.previous_msgid = Some(unescape(previous_msgid)?);
+            entry.previous_msgid =
+                Some(unescape(previous_msgid)?.to_string());
         }
 
         if let Some(previous_msgid_plural) =
             &self.previous_msgid_plural
         {
             entry.previous_msgid_plural =
-                Some(unescape(previous_msgid_plural)?);
+                Some(unescape(previous_msgid_plural)?.to_string());
         }
 
         if let Some(previous_msgctxt) = &self.previous_msgctxt {
             entry.previous_msgctxt =
-                Some(unescape(previous_msgctxt)?);
+                Some(unescape(previous_msgctxt)?.to_string());
         }
 
         Ok(entry)
@@ -486,7 +488,7 @@ mod tests {
     use crate::pofile;
 
     #[test]
-    fn poentry_constructor() {
+    fn constructor() {
         let poentry = POEntry::new(7);
 
         assert_eq!(poentry.linenum, 7);
@@ -498,7 +500,7 @@ mod tests {
     }
 
     #[test]
-    fn poentry_fuzzy() {
+    fn fuzzy() {
         let non_fuzzy_entry = POEntry::new(0);
         assert_eq!(non_fuzzy_entry.fuzzy(), false);
 
@@ -508,7 +510,7 @@ mod tests {
     }
 
     #[test]
-    fn poentry_translated() {
+    fn translated() {
         // obsolete means untranslated
         let mut obsolete_entry = POEntry::new(0);
         obsolete_entry.obsolete = true;
@@ -552,7 +554,7 @@ mod tests {
     }
 
     #[test]
-    fn poentry_merge() {
+    fn merge() {
         let mut poentry = POEntry::new(0);
         poentry.msgid = "msgid".to_string();
         poentry.msgstr = Some("msgstr".to_string());
@@ -580,7 +582,7 @@ mod tests {
     }
 
     #[test]
-    fn poentry_to_string() {
+    fn to_string() {
         let mut entry = POEntry::new(0);
 
         // empty
