@@ -1,29 +1,37 @@
 use crate::errors::EscapingError;
+use std::borrow::Cow;
 
 /// Escape characters in a PO string field
-pub fn escape(text: &str) -> String {
-    text.replace('\\', r#"\\"#)
-        .replace('\t', r"\t")
-        .replace('\n', r#"\n"#)
-        .replace('\r', r#"\r"#)
-        .replace('\u{11}', r#"\v"#)
-        .replace('\u{8}', r#"\b"#)
-        .replace('\u{12}', r#"\f"#)
-        .replace('"', r#"\""#)
+pub fn escape(text: &str) -> Cow<'_, str> {
+    let mut ret: String = String::with_capacity(text.len());
+    for char in text.chars() {
+        match char {
+            '"' => ret.push_str(r#"\""#),
+            '\n' => ret.push_str(r#"\n"#),
+            '\r' => ret.push_str(r#"\r"#),
+            '\t' => ret.push_str(r#"\t"#),
+            '\u{11}' => ret.push_str(r#"\v"#),
+            '\u{8}' => ret.push_str(r#"\b"#),
+            '\u{12}' => ret.push_str(r#"\f"#),
+            '\\' => ret.push_str(r#"\\"#),
+            c => ret.push(c),
+        }
+    }
+    ret.into()
 }
 
 struct EscapedStringInterpreter<'a> {
-    s: std::str::Chars<'a>,
+    characters: std::str::Chars<'a>,
 }
 
 impl<'a> Iterator for EscapedStringInterpreter<'a> {
     type Item = Result<char, EscapingError>;
 
     fn next(&mut self) -> Option<Self::Item> {
-        self.s.next().map(|c| match c {
-            '\\' => match self.s.next() {
+        self.characters.next().map(|c| match c {
+            '\\' => match self.characters.next() {
                 None => Err(EscapingError::EscapeAtEndOfString {
-                    text: self.s.as_str().to_string(),
+                    text: self.characters.as_str().to_string(),
                 }),
                 Some('"') => Ok('"'),
                 Some('n') => Ok('\n'),
@@ -35,7 +43,7 @@ impl<'a> Iterator for EscapedStringInterpreter<'a> {
                 Some('\\') => Ok('\\'),
                 Some(c) => {
                     Err(EscapingError::InvalidEscapedCharacter {
-                        text: self.s.as_str().to_string(),
+                        text: self.characters.as_str().to_string(),
                         character: c,
                     })
                 }
@@ -45,8 +53,15 @@ impl<'a> Iterator for EscapedStringInterpreter<'a> {
     }
 }
 
-pub fn unescape(s: &str) -> Result<String, EscapingError> {
-    (EscapedStringInterpreter { s: s.chars() }).collect()
+pub fn unescape(text: &str) -> Result<Cow<'_, str>, EscapingError> {
+    if text.contains('\\') {
+        (EscapedStringInterpreter {
+            characters: text.chars(),
+        })
+        .collect()
+    } else {
+        Ok(text.into())
+    }
 }
 
 #[cfg(test)]
