@@ -1,3 +1,4 @@
+use std::borrow::Cow;
 use std::collections::HashMap;
 use std::fmt;
 
@@ -66,6 +67,7 @@ fn by_previous_msgctxt_predicate(
 ///
 /// * A string as path to an existent file.
 /// * The content of a PO file as string.
+/// * The content of a PO file as bytes.
 /// * A [FileOptions] struct.
 ///
 /// # Examples
@@ -374,6 +376,7 @@ impl fmt::Display for POFile {
                         if line.is_empty() {
                             header_repr.push_str("#\n");
                         } else {
+                            header_repr.reserve(line.len() + 3);
                             header_repr.push_str("# ");
                             header_repr.push_str(line);
                             header_repr.push('\n');
@@ -486,21 +489,25 @@ impl AsBytes for POFile {
     /// let file = pofile("tests-data/all.po").unwrap();
     /// let bytes = MOFile::from(&file).as_bytes_with(MAGIC_SWAPPED, 1);
     /// ```
-    fn as_bytes(&self) -> Vec<u8> {
-        MOFile::from(self).as_bytes_with(MAGIC, 0)
+    fn as_bytes(&self) -> Cow<[u8]> {
+        let mofile = MOFile::from(self);
+        let result = mofile.as_bytes_with(MAGIC, 0);
+        Cow::Owned(result.into_owned())
     }
 
     /// Return the PO file content as a bytes vector of the MO file version
     ///
     /// Just an alias for [POFile::as_bytes], for consistency with [MOFile].
-    fn as_bytes_le(&self) -> Vec<u8> {
-        MOFile::from(self).as_bytes_with(MAGIC, 0)
+    fn as_bytes_le(&self) -> Cow<[u8]> {
+        self.as_bytes()
     }
 
     /// Return the PO file content as a bytes vector of
     /// the MO file version with big endianess
-    fn as_bytes_be(&self) -> Vec<u8> {
-        MOFile::from(self).as_bytes_with(MAGIC_SWAPPED, 0)
+    fn as_bytes_be(&self) -> Cow<[u8]> {
+        let mofile = MOFile::from(self);
+        let result = mofile.as_bytes_with(MAGIC_SWAPPED, 0);
+        Cow::Owned(result.into_owned())
     }
 }
 
